JavaCreate class

Java file create

Constructors

JavaCreate()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

create(String packageName, String defaultSavePath, List<GenClassBean> genClassBeans, {bool nullSafe = true}) → void
getTypeStr(Property property, {bool wantAddPre = false, bool showNullTag = true}) → String
cover dart type to java type wantAddPre if true, it when add pre keywords, like: public static final .....
method(List<MethodInfo> methods) → String
create method
property(GenClassBean genBean, List<Property> properties) → String
create property