MethodInfo class

Constructors

MethodInfo()
MethodInfo.fromJson(Map<String, dynamic> json)

Properties

args ↔ List<Property>
getter/setter pair
comment ↔ String
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
isAbstract ↔ bool
getter/setter pair
name ↔ String
getter/setter pair
originDeclaration ↔ String
getter/setter pair
returnType ↔ Property
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited