IAccount class abstract

Constructors

IAccount()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

all(List<int>? a, Map<String?, int> b, int? c) → Future<Map<int, bool>>
getList(String? name, String password, String? name2, String password3, String? namefe, String passwordeff) → Future<List<String>?>
getMap() → Future<Map<String?, int>>
getToken() → Future<String?>
////// comment for getToken
login(String? name, Object password) → Future<String?>
logout() → void
isolate comment
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setMap(Map<int, bool>? a) → void
testEnum(MyEnum a) → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited