GenClassBean class

Constructors

GenClassBean()
GenClassBean.fromJson(Map<String, dynamic> json)

Properties

channelName ↔ String
getter/setter pair
classInfo ↔ ClassInfo
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
imports ↔ List<String>
getter/setter pair
methods ↔ List<MethodInfo>
getter/setter pair
path ↔ String
getter/setter pair
properties ↔ List<Property>
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
savePath ↔ String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited